blatr: Send Emails Using 'Blat' for Windows
Description
'Blat' is a feature-rich command line email tool for Windows. The
blatr package is a wrapper for using 'Blat' from within R. For
information about 'Blat' and its options, see http://www.blat.net, for
the 'Blat' license, see http://www.blat.net/?docs/license.txt.
Details
To use the blatr package, 'Blat' needs to be installed. This can be
done manually, by downloading the executables from the website
www.blat.net and place them in the blatr installation
directory, i.e. in /path/to/R/library/blatr/. You can also use
blatr:::install_blat to let blatr do it for you. You can always
check that the needed files are placed correctly using
blatr:::check_install. Note that these functions are not exported, as
they are generally not needed when blatr is properly set up. The files
installed by blatr:::install_blat are hosted on the blatr development
page at http://GitHub.com/smbache/blatr. To get started, see the
documentation for blat.